@@ -646,13 +646,14 @@ class DataPlate:
 
 
 
-    def run_notebook(self, notebook_file_path, instance_type = "ml.m5.large", parameters = "{}", max_time_limit_minutes = 180, securityGroupIds = [], subnets= [], role = None):
+    def run_notebook(self, notebook_file_path, instance_type = "ml.m5.large", parameters = "{}", image = None, max_time_limit_minutes = 180, securityGroupIds = [], subnets= [], role = None):
         """ Run a notebook in SageMaker Processing producing a new output notebook.
         Args:
             notebook (str): The notebook file path.
             input_path (str): The S3 object containing the notebook. If this is None, the `notebook` argument is
                               taken as a local file to upload (default: None).
             parameters (dict): The dictionary of parameters to pass to the notebook (default: {}).
+            image (str): The name of the image (e.g. my-tensorflow) , default: notebook-runner
             instance_type (str): The SageMaker instance to use for executing the job (default: ml.m5.large).
             max_time_limit_minutes : maximum minutes to run before force stop
             securityGroupIds : a list of securityGroup Ids of aws for the processing job to communicate with, in case communication with other resources, e.g. internal dataplate service, is needed
@@ -683,6 +684,8 @@ class DataPlate:
                 params['parameters'] = parameters
             if max_time_limit_minutes:
                 params['timelimit_minutes'] = max_time_limit_minutes
+            if image:
+                params['image'] = image
             params['SecurityGroupIds'] = json.dumps(securityGroupIds)#','.join(['"%s"' % w for w in securityGroupIds])
             params['Subnets'] = json.dumps(subnets)#','.join(['"%s"' % w for w in subnets])
             params['notebook_name'] = notebook_name if notebook_name else ""
@@ -1217,7 +1220,7 @@ class DataPlate:
 
 
 
-    def schedule_notebook(self, notebook_file_path, rule_name = None, schedule = None, event_pattern = None, instance_type = "ml.m5.large", parameters = "{}", max_time_limit_minutes = 180, securityGroupIds = [], subnets= [], role = None):
+    def schedule_notebook(self, notebook_file_path, rule_name = None, schedule = None, event_pattern = None, instance_type = "ml.m5.large", parameters = "{}", image = None, max_time_limit_minutes = 180, securityGroupIds = [], subnets= [], role = None):
         """ Create a schedule for invoking a notebook in a specific cron/rate based intervals
 
             Creates a scheduled rule to invoke the notebook (calling run_notebook) on the provided schedule or in response
@@ -1241,6 +1244,7 @@ class DataPlate:
                 input_path (str): The S3 object containing the notebook. If this is None, the `notebook` argument is
                                   taken as a local file to upload (default: None).
                 parameters (dict): The dictionary of parameters to pass to the notebook (default: {}).
+                image (str): The name of the image (e.g. my-tensorflow) , default: notebook-runner
                 instance_type (str): The SageMaker instance to use for executing the job (default: ml.m5.large).
                 max_time_limit_minutes : maximum minutes to run before force stop
                 securityGroupIds : a list of securityGroup Ids of aws for the processing job to communicate with, in case communication with other resources, e.g. internal dataplate service, is needed
@@ -1269,6 +1273,8 @@ class DataPlate:
                 params['parameters'] = parameters
             if max_time_limit_minutes:
                 params['timelimit_minutes'] = max_time_limit_minutes
+            if image:
+                params['image'] = image
             params['SecurityGroupIds'] = json.dumps(securityGroupIds)
             params['Subnets'] = json.dumps(subnets)
             params['notebook_name'] = notebook_name if notebook_name else ""
@@ -1330,7 +1336,7 @@ class DataPlate:
             raise Error(e)
 
 
-    def run_notebook_after_schedule(self, notebook_file_path, rule_name = None, trigger_rule_name = None, trigger_rule_status = "Completed" ,instance_type = "ml.m5.large", parameters = "{}", max_time_limit_minutes = 180, securityGroupIds = [], subnets= [], role = None):
+    def run_notebook_after_schedule(self, notebook_file_path, rule_name = None, trigger_rule_name = None, trigger_rule_status = "Completed" ,instance_type = "ml.m5.large", parameters = "{}", image = None, max_time_limit_minutes = 180, securityGroupIds = [], subnets= [], role = None):
         """invoke a notebook run after another scheduled notebook Completed/InProgress/Failed.
 
             Creates a rule to invoke the notebook once a scheduled notebook rule status changed to Completed/InProgress/Failed
@@ -1350,6 +1356,7 @@ class DataPlate:
                 input_path (str): The S3 object containing the notebook. If this is None, the `notebook` argument is
                                   taken as a local file to upload (default: None).
                 parameters (dict): The dictionary of parameters to pass to the notebook (default: {}).
+                image (str): The name of the image (e.g. my-tensorflow) , default: notebook-runner
                 instance_type (str): The SageMaker instance to use for executing the job (default: ml.m5.large).
                 max_time_limit_minutes : maximum minutes to run before force stop
                 securityGroupIds : a list of securityGroup Ids of aws for the processing job to communicate with, in case communication with other resources, e.g. internal dataplate service, is needed
@@ -1378,6 +1385,8 @@ class DataPlate:
                 params['parameters'] = parameters
             if max_time_limit_minutes:
                 params['timelimit_minutes'] = max_time_limit_minutes
+            if image:
+                params['image'] = image
             params['SecurityGroupIds'] = json.dumps(securityGroupIds)
             params['Subnets'] = json.dumps(subnets)
             params['notebook_name'] = notebook_name if notebook_name else ""
@@ -1436,7 +1445,7 @@ class DataPlate:
 
 
 
-    def run_notebook_after_notebook(self, notebook_file_path, rule_name = None, trigger_notebook_name = None, trigger_notebook_status = "Completed" ,instance_type = "ml.m5.large", parameters = "{}", max_time_limit_minutes = 180, securityGroupIds = [], subnets= [], role = None):
+    def run_notebook_after_notebook(self, notebook_file_path, rule_name = None, trigger_notebook_name = None, trigger_notebook_status = "Completed" ,instance_type = "ml.m5.large", parameters = "{}", image = None, max_time_limit_minutes = 180, securityGroupIds = [], subnets= [], role = None):
         """invoke a notebook run after another scheduled notebook Completed/InProgress/Failed.
 
             Creates a rule to invoke the notebook once a scheduled notebook rule status changed to Completed/InProgress/Failed
@@ -1456,6 +1465,7 @@ class DataPlate:
                 input_path (str): The S3 object containing the notebook. If this is None, the `notebook` argument is
                                   taken as a local file to upload (default: None).
                 parameters (dict): The dictionary of parameters to pass to the notebook (default: {}).
+                image (str): The name of the image (e.g. my-tensorflow) , default: notebook-runner
                 instance_type (str): The SageMaker instance to use for executing the job (default: ml.m5.large).
                 max_time_limit_minutes : maximum minutes to run before force stop
                 securityGroupIds : a list of securityGroup Ids of aws for the processing job to communicate with, in case communication with other resources, e.g. internal dataplate service, is needed
@@ -1484,6 +1494,8 @@ class DataPlate:
                 params['parameters'] = parameters
             if max_time_limit_minutes:
                 params['timelimit_minutes'] = max_time_limit_minutes
+            if image:
+                params['image'] = image
             params['SecurityGroupIds'] = json.dumps(securityGroupIds)
             params['Subnets'] = json.dumps(subnets)
             params['notebook_name'] = notebook_name if notebook_name else ""
